package OnlineShop.domain.JTest;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.*;
import OnlineShop.domain.*;

class JTest {
	Kaufhalle kaufhalle;

	@BeforeEach
	void setUp() throws Exception {
		kaufhalle = new Kaufhalle();
	}

	@Test
	void test() throws Exception {
		kaufhalle.produkteLadenImSystem();
		kaufhalle.addProduktZuWarenkorb("hut", 10);

		kaufhalle.addProduktZuWarenkorb("hut", 5);

		kaufhalle.loginKunde("Obai", "Mannheim");
		kaufhalle.bestellen();
		kaufhalle.speichereBestellung();

		kaufhalle.addProduktZuWarenkorb("hut", 5);
		kaufhalle.loginKunde("Omar", "Mannheim");
		kaufhalle.bestellen();
		kaufhalle.speichereBestellung();
	}

}
